@@ -1,6 +1,6 @@
 package Treex;
-{
-  $Treex::VERSION = '0.08051';
+BEGIN {
+  $Treex::VERSION = '0.08083';
 }
 use strict;
 use warnings;
@@ -16,7 +16,7 @@ Treex - Natural Language Processing framework
 
 =head1 VERSION
 
-version 0.08051
+version 0.08083
 
 =head1 INTRODUCTION
 
@@ -192,10 +192,12 @@ Jan Ptáček
 
 Rudolf Rosa
 
+Josef Toman
+
 Daniel Zeman
 
 =head1 COPYRIGHT AND LICENSE
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
