@@ -1,6 +1,6 @@
 package Treex::Core::Document;
-{
-  $Treex::Core::Document::VERSION = '0.08051';
+BEGIN {
+  $Treex::Core::Document::VERSION = '0.08083';
 }
 
 use Moose;
@@ -17,7 +17,7 @@ with 'Treex::Core::WildAttr';
 
 use Scalar::Util qw( weaken reftype );
 
-use PerlIO::gzip;
+use PerlIO::via::gzip;
 use Storable;
 
 has loaded_from => ( is => 'rw', isa => 'Str', default => '' );
@@ -482,8 +482,10 @@ sub save {
     my ($filename) = @_;
 
     if ( $filename =~ /\.streex$/ ) {
-        open( my $F, ">:gzip", $filename ) or log_fatal $!; ## no critic (RequireBriefOpen)
-        Storable::nstore_fd( $self, *$F ) or log_fatal $!;
+        open( my $F, ">:via(gzip)", $filename ) or log_fatal $!;
+        print $F Storable::nfreeze( $self );
+        close $F;
+        # using  Storable::nstore_fd($self,*$F) emits 'Inappropriate ioctl for device'
     }
 
     else {
@@ -513,16 +515,25 @@ sub retrieve_storable {
 
     my $FILEHANDLE;
 
+    my $stringified_doc;
+
     if ( ref($file) and reftype($file) eq 'GLOB' ) {
         $FILEHANDLE = $file;
     }
     else {
         log_fatal "filename=$file, but Treex::Core::Document->retrieve(\$filename) can be used only for .streex files"
             unless $file =~ /\.streex$/;
-        open $FILEHANDLE, "<:gzip", $file or log_fatal($!);  ## no critic (RequireBriefOpen)
+        open $FILEHANDLE, "<:via(gzip)", $file or log_fatal($!);
     }
 
-    my $retrieved_doc = Storable::retrieve_fd(*$FILEHANDLE) or log_fatal($!);
+    my $serialized;
+    # reading it this way is silly, but both slurping the file or
+    #  using Storable::retrieve_fd lead to errors when used with via(gzip)
+    while (<$FILEHANDLE>) {
+        $serialized .= $_;
+    }
+    #    my $retrieved_doc = Storable::retrieve_fd(*$FILEHANDLE) or log_fatal($!);
+    my $retrieved_doc = Storable::thaw( $serialized ) or log_fatal $!;
     return $retrieved_doc;
 }
 
@@ -544,7 +555,7 @@ Treex::Core::Document - representation of a text and its linguistic analyses in
 
 =head1 VERSION
 
-version 0.08051
+version 0.08083
 
 =head1 DESCRIPTION
 
@@ -728,4 +739,4 @@ Ondřej Dušek <odusek@ufal.mff.cuni.cz>
 
 Copyright © 2011-2012 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
